#!/usr/bin/python
"""
This file is part of jam-control.

jam-control is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

fedora-audio-control is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with jam-control.  If not, see <http://www.gnu.org/licenses/>.
"""

from subprocess import *
import dbus
from util import which

name_base = 'org.jackaudio'
control_interface_name = name_base + '.JackControl'
configure_interface_name = name_base + '.Configure'
service_name = name_base + '.service'

class JackDbusController():
    """
    This class must have the same methods and return statements as jackController. 
    The main app should not know which one it's using
    """
    
    def __init__(self):
        """
        Check to see if jack_control is installed (from jack-audio-connection-kit-dbus-example-clients)
        Please move jack_cotrol to jack-audio-connection-kit-dbus. 
        Pulse has it's pacmd, jack deserves a default equivalent
        
        """
        if which("jack_control") != None:
            self.hasJackControl = True
        else:
            self.hasJackControl = False
        
        self.bus = dbus.SessionBus()        
        self.controller = self.bus.get_object(service_name, "/org/jackaudio/Controller")
        self.control_iface = dbus.Interface(self.controller, control_interface_name)
        self.configure_iface = dbus.Interface(self.controller, configure_interface_name)
    
    
    def stopJack(self):
        if self.hasJackControl:
            call("jack_control stop", shell= True)
        else:
            self.control_iface.StopServer()                            
        
    def startJack(self):
        if self.hasJackControl:
            call("jack_control start", shell= True)
        else:       
            self.control_iface.StartServer()
            

    def getStatus(self):
        if self.hasJackControl:        
            try:
                out = check_output("jack_control status", shell=True)
                if out.count("started") > 0:
                    return True
                else:
                    return False
            except CalledProcessError:
                return False
        else:
            if self.control_iface.IsStarted():
                return True
            else:
                return False
            
            

